package com.yijia.station.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yijia.station.mapper.StationOilGunMapper;
import com.yijia.station.domain.StationOilGun;
import com.yijia.station.service.IStationOilGunService;

/**
 * 油枪管理Service业务层处理
 * 
 * @author yijia
 * @date 2020-12-09
 */
@Service
public class StationOilGunServiceImpl implements IStationOilGunService 
{
    @Autowired
    private StationOilGunMapper stationOilGunMapper;

    /**
     * 查询油枪管理
     * 
     * @param oilGunId 油枪管理ID
     * @return 油枪管理
     */
    @Override
    public StationOilGun selectStationOilGunById(Long oilGunId)
    {
        return stationOilGunMapper.selectStationOilGunById(oilGunId);
    }

    /**
     * 查询油枪管理列表
     * 
     * @param stationOilGun 油枪管理
     * @return 油枪管理
     */
    @Override
    public List<StationOilGun> selectStationOilGunList(StationOilGun stationOilGun)
    {
        return stationOilGunMapper.selectStationOilGunList(stationOilGun);
    }

    /**
     * 新增油枪管理
     * 
     * @param stationOilGun 油枪管理
     * @return 结果
     */
    @Override
    public int insertStationOilGun(StationOilGun stationOilGun)
    {
        return stationOilGunMapper.insertStationOilGun(stationOilGun);
    }

    /**
     * 修改油枪管理
     * 
     * @param stationOilGun 油枪管理
     * @return 结果
     */
    @Override
    public int updateStationOilGun(StationOilGun stationOilGun)
    {
        return stationOilGunMapper.updateStationOilGun(stationOilGun);
    }

    /**
     * 批量删除油枪管理
     * 
     * @param oilGunIds 需要删除的油枪管理ID
     * @return 结果
     */
    @Override
    public int deleteStationOilGunByIds(Long[] oilGunIds)
    {
        return stationOilGunMapper.deleteStationOilGunByIds(oilGunIds);
    }

    /**
     * 删除油枪管理信息
     * 
     * @param oilGunId 油枪管理ID
     * @return 结果
     */
    @Override
    public int deleteStationOilGunById(Long oilGunId)
    {
        return stationOilGunMapper.deleteStationOilGunById(oilGunId);
    }
}
